Module types

Module types 

Core data structures

Structs

BaseType
Base type information (without array specifiers)
Constant
Constant definition
Field
Field definition
Type
Type information including array specifiers

Enums

AnnotationValue
Annotation values can be strings, booleans, or lists of strings
Value
Value that can be assigned to fields or constants

Type Aliases

Annotations
Annotations for fields, constants, and messages