pub fn parse_primitive_value_string(
primitive_type: &str,
value_string: &str,
) -> ParseResult<PrimitiveValue>Expand description
Parse a primitive value from string
Errors
Returns an error if:
- The primitive type is not recognized or supported
- The value string cannot be parsed for the specified primitive type
- The value is out of range for numeric types
- String literals have invalid quote formats or escape sequences